# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel
from .special_bet_request import SpecialBetRequest


@JsonMap({})
class MultiBetRequestSpecialBetRequest(BaseModel):
    """MultiBetRequestSpecialBetRequest

    :param bets: The individual bets., defaults to None
    :type bets: List[SpecialBetRequest], optional
    """

    def __init__(self, bets: List[SpecialBetRequest] = None):
        if bets is not None:
            self.bets = self._define_list(bets, SpecialBetRequest)
