# This file was generated by liblab | https://liblab.com/

from enum import Enum


class BetStatuses(Enum):
    """An enumeration representing different categories.

    :cvar WON: "WON"
    :vartype WON: str
    :cvar LOSE: "LOSE"
    :vartype LOSE: str
    :cvar CANCELLED: "CANCELLED"
    :vartype CANCELLED: str
    :cvar REFUNDED: "REFUNDED"
    :vartype REFUNDED: str
    :cvar NOT_ACCEPTED: "NOT_ACCEPTED"
    :vartype NOT_ACCEPTED: str
    :cvar ACCEPTED: "ACCEPTED"
    :vartype ACCEPTED: str
    :cvar PENDING_ACCEPTANCE: "PENDING_ACCEPTANCE"
    :vartype PENDING_ACCEPTANCE: str
    """

    WON = "WON"
    LOSE = "LOSE"
    CANCELLED = "CANCELLED"
    REFUNDED = "REFUNDED"
    NOT_ACCEPTED = "NOT_ACCEPTED"
    ACCEPTED = "ACCEPTED"
    PENDING_ACCEPTANCE = "PENDING_ACCEPTANCE"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, BetStatuses._member_map_.values()))
