# This file was generated by liblab | https://liblab.com/

from enum import Enum


class BetsGetBetsByTypeV4BetType(Enum):
    """An enumeration representing different categories.

    :cvar SPREAD: "SPREAD"
    :vartype SPREAD: str
    :cvar MONEYLINE: "MONEYLINE"
    :vartype MONEYLINE: str
    :cvar TOTAL_POINTS: "TOTAL_POINTS"
    :vartype TOTAL_POINTS: str
    :cvar TEAM_TOTAL_POINTS: "TEAM_TOTAL_POINTS"
    :vartype TEAM_TOTAL_POINTS: str
    :cvar SPECIAL: "SPECIAL"
    :vartype SPECIAL: str
    :cvar PARLAY: "PARLAY"
    :vartype PARLAY: str
    :cvar TEASER: "TEASER"
    :vartype TEASER: str
    :cvar MANUAL: "MANUAL"
    :vartype MANUAL: str
    """

    SPREAD = "SPREAD"
    MONEYLINE = "MONEYLINE"
    TOTAL_POINTS = "TOTAL_POINTS"
    TEAM_TOTAL_POINTS = "TEAM_TOTAL_POINTS"
    SPECIAL = "SPECIAL"
    PARLAY = "PARLAY"
    TEASER = "TEASER"
    MANUAL = "MANUAL"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(lambda x: x.value, BetsGetBetsByTypeV4BetType._member_map_.values())
        )
