# This file was generated by liblab | https://liblab.com/

from enum import Enum


class SortDir(Enum):
    """An enumeration representing different categories.

    :cvar ASC: "ASC"
    :vartype ASC: str
    :cvar DESC: "DESC"
    :vartype DESC: str
    """

    ASC = "ASC"
    DESC = "DESC"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, SortDir._member_map_.values()))
