# This file was generated by liblab | https://liblab.com/

from enum import Enum


class OddsFormat(Enum):
    """An enumeration representing different categories.

    :cvar AMERICAN: "AMERICAN"
    :vartype AMERICAN: str
    :cvar DECIMAL: "DECIMAL"
    :vartype DECIMAL: str
    :cvar HONGKONG: "HONGKONG"
    :vartype HONGKONG: str
    :cvar INDONESIAN: "INDONESIAN"
    :vartype INDONESIAN: str
    :cvar MALAY: "MALAY"
    :vartype MALAY: str
    """

    AMERICAN = "AMERICAN"
    DECIMAL = "DECIMAL"
    HONGKONG = "HONGKONG"
    INDONESIAN = "INDONESIAN"
    MALAY = "MALAY"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, OddsFormat._member_map_.values()))
